@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2023  Thomas Okken
+ * Copyright (C) 2004-2024  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -177,7 +177,7 @@ int docmd_comb(arg_struct *arg) {
     #ifdef BCD_MATH
         s = x == 0 ? 1 : pow(10, 1 + floor(log10(x)));
     #elif ANDROID
-        s = x == 0 ? 1 : pow(2, 1 + floor(log(x) / log(2)));
+        s = x == 0 ? 1 : pow(2, 1 + floor(log(x) / log(phloat(2))));
     #else
         s = x == 0 ? 1 : pow(2, 1 + floor(log2(x)));
     #endif
@@ -536,12 +536,15 @@ int docmd_xeq(arg_struct *arg) {
             int4 dummy2;
             bool dummy3;
             pop_rtn_addr(&dummy1, &dummy2, &dummy3);
-        }
+        } else
+            save_csld();
         return err;
     } else {
         int err = docmd_gto(arg);
         if (err != ERR_NONE)
             return err;
+        else
+            save_csld();
         clear_all_rtns();
         return ERR_RUN;
     }
@@ -837,7 +840,7 @@ static void pixel_helper(phloat dx, phloat dy) {
     dx = dx < 0 ? -floor(-dx + 0.5) : floor(dx + 0.5);
     dy = dy < 0 ? -floor(-dy + 0.5) : floor(dy + 0.5);
     int x = dx < -132 ? -132 : dx > 132 ? 132 : to_int(dx);
-    int y = dy < -132 ? -132 : dy > 132 ? 132 : to_int(dy);
+    int y = dy < -17 ? -17 : dy > 17 ? 17 : to_int(dy);
     int i;
     int dot = 1;
     if (x < 0) {
@@ -1759,25 +1762,13 @@ int docmd_stop(arg_struct *arg) {
 int docmd_newmat(arg_struct *arg) {
     vartype *m;
 
-    phloat x = ((vartype_real *) stack[sp])->x;
-    if (x <= -2147483648.0 || x >= 2147483648.0)
+    int4 row, col;
+    if (!dim_to_int4(stack[sp - 1], &row))
         return ERR_DIMENSION_ERROR;
-    int4 xx = to_int4(x);
-    if (xx == 0)
+    if (!dim_to_int4(stack[sp], &col))
         return ERR_DIMENSION_ERROR;
-    if (xx < 0)
-        xx = -xx;
 
-    phloat y = ((vartype_real *) stack[sp - 1])->x;
-    if (y <= -2147483648.0 || y >= 2147483648.0)
-        return ERR_DIMENSION_ERROR;
-    int4 yy = to_int4(y);
-    if (yy == 0)
-        return ERR_DIMENSION_ERROR;
-    if (yy < 0)
-        yy = -yy;
-
-    m = new_realmatrix(yy, xx);
+    m = new_realmatrix(row + 1, col + 1);
     if (m == NULL)
         return ERR_INSUFFICIENT_MEMORY;
     else
