@@ -1,6 +1,6 @@
 /*****************************************************************************
  * Free42 -- an HP-42S calculator simulator
- * Copyright (C) 2004-2023  Thomas Okken
+ * Copyright (C) 2004-2024  Thomas Okken
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -30,6 +30,7 @@
 
 int resolve_ind_arg(arg_struct *arg, char *buf = NULL, int *len = NULL);
 int arg_to_num(arg_struct *arg, int4 *num);
+bool dim_to_int4(vartype *dim, int4 *res);
 int recall_result_silently(vartype *v);
 int recall_result(vartype *v);
 int recall_two_results(vartype *x, vartype *y);
@@ -106,5 +107,8 @@ const char *phloat2program(phloat d);
 int easy_phloat2string(phloat d, char *buf, int buflen, int base_mode);
 int ip2revstring(phloat d, char *buf, int buflen);
 
+int matedit_get(vartype **res);
+void leave_matrix_editor();
+
 
 #endif
