@@ -25,6 +25,8 @@ int math_tan(phloat x, phloat *y, bool rad);
 int math_asinh(phloat xre, phloat xim, phloat *yre, phloat *yim);
 int math_acosh(phloat xre, phloat xim, phloat *yre, phloat *yim);
 int math_atanh(phloat xre, phloat xim, phloat *yre, phloat *yim);
+int math_ln(phloat xre, phloat xim, phloat *yre, phloat *yim);
 int math_sqrt(phloat xre, phloat xim, phloat *yre, phloat *yim);
+int math_inv(phloat xre, phloat xim, phloat *yre, phloat *yim);
 
 #endif
